<!-- These are examples of badges you might want to add to your README:
     please update the URLs accordingly

[![Built Status](https://api.cirrus-ci.com/github/<USER>/lumeo.svg?branch=main)](https://cirrus-ci.com/github/<USER>/lumeo)
[![ReadTheDocs](https://readthedocs.org/projects/lumeo/badge/?version=latest)](https://lumeo.readthedocs.io/en/stable/)
[![Coveralls](https://img.shields.io/coveralls/github/<USER>/lumeo/main.svg)](https://coveralls.io/r/<USER>/lumeo)
[![PyPI-Server](https://img.shields.io/pypi/v/lumeo.svg)](https://pypi.org/project/lumeo/)
[![Conda-Forge](https://img.shields.io/conda/vn/conda-forge/lumeo.svg)](https://anaconda.org/conda-forge/lumeo)
[![Monthly Downloads](https://pepy.tech/badge/lumeo/month)](https://pepy.tech/project/lumeo)
[![Twitter](https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter)](https://twitter.com/lumeo)
-->
# lumeo

>Helper library for Lumeo video analytics platform

Lumeo is a flexible, open no/low code video analytics platform that enables you to generate actionable insights and alerts using AI-based video analytics.
This package provides :
1) a set of helpers to be used within Lumeo's [custom function node](https://docs.lumeo.com/docs/custom-function-node)
2) a set of scripts that make it easy to use Lumeo's API for importing cameras, bulk processing video, etc.

### Useful Links

- [Lumeo](https://lumeo.com/)
- [Lumeo Documentation Hub](https://docs.lumeo.com/)
- [API Reference](https://docs.lumeo.com/reference)
